@@ -1,12 +1,12 @@
 import os
-from dataclasses import dataclass, asdict
+from dataclasses import asdict, dataclass
 from typing import Optional
 
-from daml_dit_api import \
-    DABL_META_NAME
+from daml_dit_api import DABL_META_NAME
 
 from .log import FAIL, LOG
 
+
 @dataclass(frozen=True)
 class Configuration:
     health_port: int
